<?php
/*------------------------------------------------------------
 * Table of Contents
 *
 * 1.  Row
 * 2.  Column
 * 3.  Vertical Spacer / Gap
 * 4.  Horizontal Spacer / Gap
 * 5.  Separator
 * 6.  Dropcap	
 * 7.  Highlight
 * 8.  Icons
 * 9.  Blockquote
 * 10. Button
 * 11. Text Style
 * 12. Tooltip
 * 13. Lists
 * 14. Video Wrapper
 * 15. Promobox
 *------------------------------------------------------------*/

/*------------------------------------------------------------
 * Remove extra P tags
 *------------------------------------------------------------*/
add_filter("the_content", "charvi_shortcode_format");
function charvi_shortcode_format($content) {
	// array of custom shortcodes requiring the fix
	$block = join("|",array( "dtr_row","dtr_column","dtr_spacer","dtr_spacer_wide","dtr_separator","dtr_dropcap","dtr_highlight","dtr_icon","dtr_blockquote","dtr_button","dtr_text_style","dtr_tooltip","dtr_team","dtr_team_styled","dtr_portfolio_grid","list","ordered_list","list_item", "dtr_listicon", "dtr_portfolio_tax", "dtr_social_share", "dtr_video_wrapper", "dtr_checkmark_list", "dtr_circle_list", "dtr_star_list", "dtr_heart_list", "dtr_circle_arrow_list", "dtr_arrow_list", "dtr_checkmark_square_list", "dtr_checkmark_circle_list", "dtr_promobox", "dtr_packagebox", "dtr_about" ) );

	// opening tag
	$rep = preg_replace("/(<p>)?\[($block)(\s[^\]]+)?\](<\/p>|<br \/>)?/","[$2$3]",$content);
	// closing tag
	$rep = preg_replace("/(<p>)?\[\/($block)](<\/p>|<br \/>)?/","[/$2]",$rep);
	return $rep;
}

/*
 * @param $content
 * @param bool $autop
 * @return string
 */
if ( ! function_exists( 'charvi_remove_wpautop' ) ) {
	function charvi_remove_wpautop( $content, $autop = false ) {
		if ( $autop ) { // Possible to use !preg_match('('.WPBMap::getTagsRegexp().')', $content)
			$content = wpautop( preg_replace( '/<\/?p\>/', "\n", $content ) . "\n" );
		}
		return do_shortcode( shortcode_unautop( $content ) );
	}
}

/*------------------------------------------------------------
 * 1. Row
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_row_sc' ) ) {
	function charvi_row_sc( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'padding' 		=> '',
			'margin' 		=> '',
			'class'			=> '',
			'return_class'	=> '',
		), $atts ) );
		$output = '';
		// class
		if( $class ) {
			$return_class = ' class="'. esc_attr( $class ) .'"';
		} 
		// style
		$add_style = array();
		if( $padding  ) {
			$add_style[] = 'padding:'. $padding .';';
		} 
		if( $margin ) {
			$add_style[] = 'margin:'. $margin .';';
		} 
		$add_style = implode('', $add_style);
	
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '"';
		}
		// output
		if ( $class || $add_style ) {
			$output .= '<div' . $return_class . '' . $add_style. '>';
		}
				$output .= '<div class="row">' . do_shortcode( $content ) . '</div>';
		if ( $class || $add_style ) {
			$output .= '</div>';
		}
		// return output
		return $output;
	}
}
add_shortcode( 'dtr_row', 'charvi_row_sc' );

/*------------------------------------------------------------
 * 2. Column
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_column_sc' ) ) {
	function charvi_column_sc( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'width' 		=> '',
			'class'			=> '',
			'return_class'	=> '',
			), $atts ) );
		
		switch ( $width ) {
			case "span12"   : $default_class = "col-md-12 col-sm-12 col-xs-12"; break;
			case "span11"   : $default_class = "col-md-11 col-sm-11 col-xs-12"; break;
			case "span10"   : $default_class = "col-md-10 col-sm-10 col-xs-12"; break;
			case "span9"	: $default_class = "col-md-9 col-sm-9 col-xs-12"; break;
			case "span8"	: $default_class = "col-md-8 col-sm-8 col-xs-12"; break;
			case "span7"    : $default_class = "col-md-7 col-sm-7 col-xs-12"; break;
			case "span6"    : $default_class = "col-md-6 col-sm-6 col-xs-12"; break;
			case "span5"    : $default_class = "col-md-5 col-sm-5 col-xs-12"; break;
			case "span4"    : $default_class = "col-md-4 col-sm-4 col-xs-12"; break;
			case "span3"    : $default_class = "col-md-3 col-sm-3 col-xs-12"; break;
			case "span2"    : $default_class = "col-md-2 col-sm-2 col-xs-12"; break;
			case "span1"    : $default_class = "col-md-1 col-sm-1 col-xs-12"; break;
			default       	: $default_class = "col-md-12 col-sm-12 col-xs-12";
		}
		
		if( $class ) {
			$return_class = ' '. esc_attr( $class ) .'';
		} 
		// output
		return '<div class="' . $default_class . '' . $return_class . '">' . do_shortcode( $content ) . '</div>';
	}
}
add_shortcode( 'dtr_column', 'charvi_column_sc' );

/*------------------------------------------------------------
 * 3. Vertical Spacer / Gap
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_spacer_sc' ) ) {
	function charvi_spacer_sc( $atts, $content ) {
		extract ( shortcode_atts( array(
			'height'	=> '', // in px
		), $atts ) );
		return '<div class="spacer" style="height: ' . esc_attr( $height ) . ';"></div>';
	}
}
add_shortcode( 'dtr_spacer', 'charvi_spacer_sc' );
	
/*------------------------------------------------------------
 * 4. Horizontal Spacer / Gap
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_wide_spacer_sc' ) ) {
	function charvi_wide_spacer_sc( $atts, $content ) {
		extract ( shortcode_atts( array(
			'width'       => '', // in px
		), $atts ) );
		return '<span class="spacer-wide" style="width: ' . esc_attr( $width ) . ';"></span>';
	}
}
add_shortcode( 'dtr_spacer_wide', 'charvi_wide_spacer_sc' );

/*------------------------------------------------------------
 * 5. Separator
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_separator_sc' ) ) {
	function charvi_separator_sc( $atts, $content=null ) {
		extract ( shortcode_atts( array(
			'width'			=> '', 
			'color'			=> '', 
			'margin_top'	=> '', 
			'margin_bottom'	=> '', 
			'align'			=> '', 
			'border_style'	=> '', 
			'border_width'	=> '', 
		), $atts ) );
		// align
		if( $align == 'left' ){
			$return_align = ' left-separator';
		} elseif( $align == 'right' ){
			$return_align = ' right-separator';
		} elseif( $align == 'center' ){
			$return_align = '';
		} else {
			$return_align = '';
		}
		// style
		$add_style = array();
		if ( $width ) {
			$add_style[] = 'width: '. $width .';';
		} 
		if ( $border_width ) {
			$add_style[] = 'border-top-width: '. $border_width .';';
		} 
		if ( $border_style ) {
			$add_style[] = 'border-top-style: '. $border_style .';';
		} 
		if ( $color ) {
			$add_style[] = 'border-color: '. $color .';';
		} 
		if ( $margin_top ) {
			$add_style[] = 'margin-top: '. $margin_top .';';
		} 
		if ( $margin_bottom ) {
			$add_style[] = 'margin-bottom: '. $margin_bottom .';';
		} 
		$add_style = implode('', $add_style);
		
		if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
		}
		return '<div class="line-separator' . esc_attr( $return_align ) . '"' . $add_style . '></div>';
	}
}
add_shortcode( 'dtr_separator', 'charvi_separator_sc' );

/*------------------------------------------------------------
 * 6. Dropcap
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_dropcap_sc' ) ) {
	function charvi_dropcap_sc( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'bgcolor'	=> '', 
			'color'		=> '', 
			'style' 	=> '', // default/circle/square
		), $atts ) );

		$add_style = array();
		if( $bgcolor != ''  ) {
			$add_style[] = 'background-color: '. $bgcolor .';';
		} 
		if( $color != ''  ) {
			$add_style[] = 'color: '. $color .';';
		} 
		$add_style = implode('', $add_style);
		
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '" ';
		}
		return '<span class="dtr-dropcap ' . esc_attr( $style ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</span>';
	}  
}
add_shortcode( 'dtr_dropcap', 'charvi_dropcap_sc' ); 
 
/*------------------------------------------------------------
 * 7. Highlight
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_text_highlight_sc' ) ) {
	function charvi_text_highlight_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'bgcolor' 	=> '', 
		'color'   	=> '', 
		'font_size'	=> '', 
	), $atts ) );
	
	$add_style = array();
	if( $bgcolor != ''  ) {
		$add_style[] = 'background-color: '. $bgcolor .';';
	} 
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	if( $font_size != ''  ) {
		$add_style[] = 'font-size: '. $font_size .';';
	} 
	$add_style = implode('', $add_style);
	
	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '" ';
	}
	return '<span class="dtr-highlight"' . $add_style . '>' . do_shortcode( $content ) . '</span>';
	}
}
add_shortcode( 'dtr_highlight', 'charvi_text_highlight_sc' );

/*------------------------------------------------------------
 * 8. Icons
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_icon_sc' ) ) {
	function charvi_icon_sc( $atts, $content ) {
		extract( shortcode_atts( array(
			'icon_name'	=> '', 
			'color' 	=> '', 
			'size' 		=> '',
		), $atts ) );
		
		$add_style = array();
		if( $color != ''  ) {
			$add_style[] = 'color: '. $color .';';
		} 
		if( $size != ''  ) {
			$add_style[] = 'font-size: '. $size .';';
		} 
		$add_style = implode('', $add_style);
		
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '" ';
		}
		
		return '<span class=" fa ' . $icon_name . '"' . $add_style . '></span>';
	}
}
add_shortcode( 'dtr_icon', 'charvi_icon_sc' );

/*------------------------------------------------------------
 * 9. Blockquote
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_blockquote_sc' ) ) {
	function charvi_blockquote_sc( $atts,  $content = null ) {
		extract( shortcode_atts( array(
			'style'			=> '',
			'return_style'	=> '',
			'class'			=> '',
			'source'		=> '',
			'return_source'	=> '',
			'half_width'		=> 'false',
			'return_half_width'		=> '',
		), $atts ) );
		
		$content = charvi_remove_wpautop($content, true);
		
		if( $half_width == 'true' ) {
			$return_half_width	= ' dtr-quote-col';	
		}
		
		if( $source ) {
			$return_source	= '<span class="dtr-quote-source">' . esc_attr ( $source ) . '</span>';	
		}
		
		if( $style == 'with_border' ) {
			return '<div class="dtr-border-quote ' . $class . '' . $return_half_width . '"><blockquote class="dtr-blockquote">' . $content . '</blockquote>' . $return_source . '</div>';
		} elseif ( $style == 'with_right_border' ) {
			return '<div class="dtr-border-quote dtr-right-border-quote ' . $class . '"><blockquote class="dtr-blockquote">' . $content . '</blockquote>' . $return_source . '</div>';
		} elseif ( $style == 'with_icon' ) {
			return '<div class="dtr-ql-format-wrapper dtr-styled-quote' . $return_half_width . '"><div class="dtr-ql-format"><blockquote class="dtr-blockquote dtr-icon-quote ' . $class . '">' . $content . '</blockquote>' . $return_source . '</div></div>';
		
		} 
	}
}
add_shortcode( 'dtr_blockquote', 'charvi_blockquote_sc' );

/*------------------------------------------------------------
 * 10. Button
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_button_sc' ) ) {
	function charvi_button_sc( $atts, $content ) {
		extract ( shortcode_atts( array(
			'size'  				=> '', 
			'target' 				=> '', 
			'return_target' 		=> '', 
			'url'   				=> '', 
			'icon_position'   		=> '', 
			'return_icon_position'	=> '', 
			'icon_name'   			=> '',
			'btn_text'				=> '', 
			'return_size'  			=> '', 
			'color'  				=> '', 
			'bg_color'  			=> '', 
			'add_padding'  			=> '', 
			'class'  				=> '', 
			'return_class' 			=> '',
			'border_color'  		=> '', 
		), $atts ) );
		
		// color styles
		$add_style = array();
		if( $color != ''  ) {
			$add_style[] = 'color: '. $color .';';
		} 
		if( $bg_color != ''  ) {
			$add_style[] = 'background-color: '. $bg_color .';';
		} 
		if( $border_color != ''  ) {
			$add_style[] = 'border-color: '. $border_color .';';
		} 
		$add_style = implode('', $add_style);
		
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '" ';
		}
		
		// icon_name
		if( $icon_name != '' ) {
			$return_icon = '<i class="' . esc_attr( $icon_name ) . '"></i>';
		} else {
			$return_icon = '';
		}

		// url
		if( $url != ''  ) {
			$return_url = ' href="' . esc_url( $url ) . '"';
		} else {
			$return_url = '';
		}
	
		// target
		if( $target == 'blank' ){
			$return_target = ' target="_blank"';
		} elseif( $target == 'self' ){
			$return_target = ' target="_self"';
		} else {
			$return_target = '';
		}
		
		// size
		if( $size == 'big' ) {
			$return_size = ' themebtn-big';
		} elseif ( $size == 'medium' ) {
			$return_size = ' themebtn-medium';
		} else { 
			$return_size = ''; 
		}

		// Icon Position
		if( $icon_position == 'left' ) {
			$return_icon_position = ' themebtn-left';
		} elseif ( $icon_position == 'right' ) {
			$return_icon_position = ' themebtn-right';
		} else { 
			$return_icon_position = ' themebtn-left'; 
		}
		
		// btn text
		if( $btn_text != ''  ) {
			$return_label = '' . esc_attr( $btn_text ) . '';
			$add_padding = '';
		} else {
			$return_label = '';
			$add_padding = ' dtr-icon-btn';
		}

		// output
		return '<a class="themebtn ' . esc_attr( $return_icon_position ) . esc_attr( $return_size ) . '' . esc_attr( $add_padding ) . ' ' . esc_attr( $class ) . '"' . $return_target . ' ' . $return_url . '' . $add_style . '>' . $return_icon . '' . $return_label . '</a>';
	}
}
add_shortcode( 'dtr_button', 'charvi_button_sc' );

/*------------------------------------------------------------
 * 11. Text style
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_text_style_sc' ) ) {
	function charvi_text_style_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'size' 				=> '', 
			'line_height'		=> '', 
			'color' 			=> '', 
			'font_weight'		=> '', 
			'letter_spacing'	=> '', 
			'class' 			=> '',
			'return_class' 		=> '',
		), $atts ) );
		
		$content = charvi_remove_wpautop($content, true);
		// style
		$add_style = array();
		if ( $size ) {
			$add_style[] = ' font-size: ' . $size . ';';
		} 
		if ( $line_height ) {
			$add_style[] = ' line-height: ' . $line_height . ';';
		} 
		if ( $color ) {
			$add_style[] = ' color: ' . $color . ';';
		} 
		if ( $font_weight ) {
			$add_style[] = ' font-weight: ' . $font_weight . ';';
		} 
		if ( $letter_spacing ) {
			$add_style[] = ' letter-spacing: ' . $letter_spacing . ';';
		} 
		$add_style = implode('', $add_style);
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '"';
		}
		
		// class
		if( $class ) {
			$return_class = ' class="'. esc_attr( $class ) .'"';
		} 
		
		return '<div' . $add_style . '' . $return_class . '>' . $content . '</div>';
	}
}
add_shortcode( 'dtr_text_style', 'charvi_text_style_sc' );

/*------------------------------------------------------------
 * 12. Tooltip
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_tooltip_sc' ) ) {
	function charvi_tooltip_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'url'       => '', 
			'title'     => '', 
			'color'     => '', 
			'font_size' => '', 
			'placement'	=> 'top', // top, bottom, left, right
		), $atts ) );
		
		$add_style = array();
		if( $color != ''  ) {
			$add_style[] = 'color: '. $color .';';
		} 
		if( $font_size != ''  ) {
			$add_style[] = 'font-size: '. $font_size .';';
		} 
		$add_style = implode('', $add_style);
		
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '" ';
		}
		
		if( $url != ''  ) {
			$return_url = 'href="' . esc_url( $url ) . '" ';
		}
		else{
			$return_url = '';
		}
		return '<a ' . $return_url . 'title="' . esc_attr( $title ) . '" data-placement="' . esc_attr( $placement ) . '" data-toggle="tooltip"' . $add_style . '>' . do_shortcode( $content ) . '</a>';
	}
}
add_shortcode( 'dtr_tooltip', 'charvi_tooltip_sc' );

/*------------------------------------------------------------
 * 13. Lists
 * @since 1.0
 *------------------------------------------------------------*/
// ul
if ( ! function_exists( 'charvi_list_sc' ) ) {
	function charvi_list_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'color'				=> '', 
			'font_size'			=> '', 
			'line_height'		=> '', 
			'list_style'		=> '', 
		), $atts ) );
		
		// add list style
		$add_style = array();
		if( $color != ''  ) {
			$add_style[] = 'color: '. $color .';';
		} 
		if( $font_size != ''  ) {
			$add_style[] = 'font-size: '. $font_size .';';
		} 
		if( $line_height != ''  ) {
			$add_style[] = 'line-height: '. $line_height .';';
		} 
		if( $list_style != ''  ) {
			$add_style[] = 'list-style-type: '. $list_style .';';
		} 
		$add_style = implode('', $add_style);
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '"';
		}
		return '<ul class="common-list" ' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
	}
}
add_shortcode( 'dtr_list', 'charvi_list_sc' );

// ol
if ( ! function_exists( 'charvi_ordered_list_sc' ) ) {
	function charvi_ordered_list_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'color'			=> '', 
			'font_size'		=> '', 
			'line_height'	=> '', 
			'list_style'	=> '', 
		), $atts ) );
		
		// add list style
		$add_style = array();
		if( $color != ''  ) {
			$add_style[] = 'color: '. $color .';';
		} 
		if( $font_size != ''  ) {
			$add_style[] = 'font-size: '. $font_size .';';
		} 
		if( $line_height != ''  ) {
			$add_style[] = 'line-height: '. $line_height .';';
		} 
		if( $list_style != ''  ) {
			$add_style[] = 'list-style-type: '. $list_style .';';
		} 
		$add_style = implode('', $add_style);
		
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '"';
		}
		return '<ol class="list" ' . $add_style . '>' . do_shortcode( $content ) . '</ol>';
	}
}
add_shortcode( 'dtr_ordered_list', 'charvi_ordered_list_sc' );

// Checkmark list
function charvi_checkmark_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-checkmark' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_checkmark_list', 'charvi_checkmark_list_sc' );

// Checkmark circle list
function charvi_checkmark_circle_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-checkmark-circle' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_checkmark_circle_list', 'charvi_checkmark_circle_list_sc' );

// Checkmark square list
function charvi_checkmark_square_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-checkmark-square' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_checkmark_square_list', 'charvi_checkmark_square_list_sc' );

// arrow list
function charvi_arrow_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-arrow' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_arrow_list', 'charvi_arrow_list_sc' );

// circle arrow list
function charvi_circle_arrow_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-arrow-circle' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_circle_arrow_list', 'charvi_circle_arrow_list_sc' );

// heart list
function charvi_heart_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-heart' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_heart_list', 'charvi_heart_list_sc' );

// star list
function charvi_star_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-star' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_star_list', 'charvi_star_list_sc' );

// circle list
function charvi_circle_list_sc( $atts, $content = null ) {
	extract ( shortcode_atts( array(
		'color'			=> '', 
		'size'			=> '', 
		'return_size'	=> '', 
    ), $atts ) );
		
   $add_style = array();
	if( $color != ''  ) {
		$add_style[] = 'color: '. $color .';';
	} 
	$add_style = implode('', $add_style);

	if ( $add_style ) {
		$add_style = wp_kses( $add_style, array() );
		$add_style = ' style="' . esc_attr($add_style) . '"';
	}
	
	if( $size == 'medium'  ) {
		$return_size = ' dtr-list-medium';
	} 
		
	return '<ul class="dtr-list-circle' . esc_attr ( $return_size ) . '"' . $add_style . '>' . do_shortcode( $content ) . '</ul>';
}
add_shortcode( 'dtr_circle_list', 'charvi_circle_list_sc' );

// li
if ( ! function_exists( 'charvi_list_item_sc' ) ) {
	function charvi_list_item_sc( $atts, $content = null ) {
		return '<li>' . do_shortcode( $content ) . '</li>';
	}
}
add_shortcode( 'dtr_list_item', 'charvi_list_item_sc' );


// List with icon
if ( ! function_exists( 'charvi_icon_list_sc' ) ) {
	function charvi_icon_list_sc( $atts, $content = null ) {
		extract( shortcode_atts( array(
		'icon_type'   		=> '',
		'color'        		=> '',
		'font_size'        => '',
		'line_height'      => '',
		'icon_color'   		=> '',
		'list_content'      => '', 
		), $atts ) );
		
		// style
		$add_style = array();
		if( $color != ''  ) {
			$add_style[] = 'color: '. $color .';';
		} 
		if( $font_size != ''  ) {
			$add_style[] = 'font-size: '. $font_size .';';
			$add_style[] = 'padding-left: '. $font_size .';';
		} 
		if( $line_height != ''  ) {
			$add_style[] = 'line-height: '. $line_height .';';
		} 
		$add_style = implode('', $add_style);
		
		if ( $add_style ) {
			$add_style = wp_kses( $add_style, array() );
			$add_style = ' style="' . esc_attr($add_style) . '"';
		}
		// icon style
		$add_style_icon = array();
		if( $icon_color != ''  ) {
			$add_style_icon[] = 'color: '. $icon_color .';';
		} 
		$add_style_icon = implode('', $add_style_icon);
		
		if ( $add_style_icon ) {
			$add_style_icon = wp_kses( $add_style_icon, array() );
			$add_style_icon = ' style="' . esc_attr($add_style_icon) . '"';
		}

		// icon_type
		if( $icon_type ) {
			$return_icon = '<i class="' . esc_attr( $icon_type ) . '"' . $add_style_icon . '></i>';
		} else {
			$return_icon = '';
		}
		
		return '<p class="dtr-list-icon"' . $add_style . '>' . $return_icon . '<span>' . $list_content . '</span></p>';
	}
}
add_shortcode( 'dtr_listicon', 'charvi_icon_list_sc' );

/*------------------------------------------------------------
 * 14. Video Wrapper
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_video_wrapper_sc' ) ) {
	function charvi_video_wrapper_sc( $atts, $content = null ) {
		return '<div class="dtr-video-wrapper">' . do_shortcode( $content ) . '</div>';
	}
}
add_shortcode( 'dtr_video_wrapper', 'charvi_video_wrapper_sc' );

/*------------------------------------------------------------
 * Testimonial 1
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_testimonial_sc' ) ) {
	function charvi_testimonial_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'id'  					=> '',
		), $atts ) );
	
		global $post;
		$args = array(
			'name'           	=> esc_attr( $id ),
			'post_type'      	=> 'dtr_testimonial',
			'post_status'    	=> 'publish',
		);
		$output = '';
		$query = new WP_Query( $args );
		if ($query->have_posts()) :	
		$output .= '<div class="dtr-testimonial">';
			while ( $query->have_posts() ) : $query->the_post();
				$output .= '<div class="dtr-testimonial-item item clearfix">';
				$thumb       			= get_post_thumbnail_id(); 
				$img_url     			= wp_get_attachment_url( $thumb, 'full' ); 
				$image       			= aq_resize( $img_url, 80, 80, true );
				$testimonial_tagline 	= get_post_meta( $post->ID, '_charvi_testimonial_tagline', true );
				$client_name 			= get_post_meta( $post->ID, '_charvi_testimonial_client_name', true );
				$client_designation 	= get_post_meta( $post->ID, '_charvi_testimonial_client_designation', true );
				// output	
				if( $testimonial_tagline ){
					$output .= '<span class="dtr-testimonial-tagline">' . esc_attr( $testimonial_tagline ) . '</span>';
				}
				$output .= '<div class="dtr-testimonial-description">';
				$content = get_the_content();
				$content = apply_filters( 'the_content', $content );
				$content = str_replace( ']]>', ']]&gt;', $content );
				$output .= $content;
				$output .= '</div>';
				if( has_post_thumbnail() || $client_name || $client_designation  ){
					$output .= '<div class="dtr-testimonial-info">';
					if ( has_post_thumbnail() ) {	
						$output .= '<span class="dtr-testimonial-img"><img src="' . esc_url( $image ) . '" alt="' . esc_attr( $client_name ) . '"/></span>';
					}
					if( $client_name || $client_designation  ){
						$output .= '<div class="dtr-testimonial-info-text">';
						if( $client_name ){
							$output .= '<h5 class="dtr-testimonial-client-name">' . esc_attr( $client_name ) . '</h5>';
						} 
						if( $client_designation ){ 
							$output .= '<span class="dtr-testimonial-client-designation">' . esc_attr( $client_designation ) . '</span>';
						} 
						$output .= '</div>';
					}
					$output .= '</div>';
				}
				$output .= '</div>';
			endwhile;
			$output .= '</div>';
			wp_reset_postdata();
		endif;
		return $output;
	}
}
add_shortcode('dtr_testimonial', 'charvi_testimonial_sc');


/*------------------------------------------------------------
 * Testimonial 2
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_testimonial_var_sc' ) ) {
	function charvi_testimonial_var_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'id'  					=> '',
		), $atts ) );
	
		global $post;
		$args = array(
			'name'           	=> esc_attr( $id ),
			'post_type'      	=> 'dtr_testimonial',
			'post_status'    	=> 'publish',
		);
		$output = '';
		$query = new WP_Query( $args );
		if ($query->have_posts()) :	
		$output .= '<div class="dtr-testimonial dtr-testimonial-style2">';
			while ( $query->have_posts() ) : $query->the_post();
				$output .= '<div class="dtr-testimonial-item item clearfix">';
				$thumb       			= get_post_thumbnail_id(); 
				$img_url     			= wp_get_attachment_url( $thumb, 'full' ); 
				$image       			= aq_resize( $img_url, 200, 200, true );
				$client_name 			= get_post_meta( $post->ID, '_charvi_testimonial_client_name', true );
				$client_designation 	= get_post_meta( $post->ID, '_charvi_testimonial_client_designation', true );
				// output	
				
				if ( has_post_thumbnail() ) {	
					$output .= '<span class="dtr-testimonial-img"><img src="' . esc_url( $image ) . '" alt="' . esc_attr( $client_name ) . '"/></span>';
				}
				
				if( $client_name ){
					$output .= '<div class="dtr-testimonial-info">';
					if( $client_name ){
						$output .= '<h5 class="dtr-testimonial-client-name">' . esc_attr( $client_name ) . '</h5>';
					} 
					if( $client_designation ){ 
						$output .= '<span class="dtr-testimonial-client-designation">' . esc_attr( $client_designation ) . '</span>';
					} 
					$output .= '</div>';
				}
				// content
				$output .= '<div class="dtr-testimonial-description">';
				$content = get_the_content();
				$content = apply_filters( 'the_content', $content );
				$content = str_replace( ']]>', ']]&gt;', $content );
				$output .= $content;
				$output .= '</div>';				
			$output .= '</div>';
			endwhile;
			$output .= '</div>';
			wp_reset_postdata();
		endif;
		return $output;
	}
}
add_shortcode('dtr_testimonial_var', 'charvi_testimonial_var_sc');

/*------------------------------------------------------------
 * Testimonial Carousel
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'charvi_testimonial_carousel_sc' ) ) {
	function charvi_testimonial_carousel_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'id'  					=> '',
			'limit'     			=> -1,
			'order'     			=> 'DESC',
			'orderby'   			=> 'date',
		), $atts ) );
	
		global $post;
		$args = array(
			'name'           	=> esc_attr( $id ),
			'post_type'      	=> 'dtr_testimonial',
			'posts_per_page'	=> esc_attr( $limit ),
			'order'          	=> esc_attr( $order ), 
			'orderby'        	=> $orderby,
			'post_status'    	=> 'publish',
		);
		$output = '';
		$query = new WP_Query( $args );
		if ($query->have_posts()) :	
		$output .= '<div class="owl-carousel dtr-owl-theme dtr-testimonial">';
			while ( $query->have_posts() ) : $query->the_post();
				$output .= '<div class="dtr-testimonial-item item clearfix">';
				$thumb       			= get_post_thumbnail_id(); 
				$img_url     			= wp_get_attachment_url( $thumb, 'full' ); 
				$image       			= aq_resize( $img_url, 80, 80, true );
				$client_name 		    = get_post_meta( $post->ID, '_charvi_client_name', true );
				$testimonial_tagline 	= get_post_meta( $post->ID, '_charvi_testimonial_tagline', true );
				$client_name 			= get_post_meta( $post->ID, '_charvi_testimonial_client_name', true );
				$client_designation 	= get_post_meta( $post->ID, '_charvi_testimonial_client_designation', true );
				// output	
				if( $testimonial_tagline ){
					$output .= '<span class="dtr-testimonial-tagline">' . esc_attr( $testimonial_tagline ) . '</span>';
				}
				$output .= '<div class="dtr-testimonial-description">';
				$content = get_the_content();
				$content = apply_filters( 'the_content', $content );
				$content = str_replace( ']]>', ']]&gt;', $content );
				$output .= $content;
				$output .= '</div>';
				$output .= '<div class="dtr-testimonial-info">';
				
				if ( has_post_thumbnail() ) {	
					$output .= '<span class="dtr-testimonial-img"><img src="' . esc_url( $image ) . '" alt="' . esc_attr( $client_name ) . '"/></span>';
				}
				
				if ( ! has_post_thumbnail() ) {	
				$align_class = ' text-center';
				
				} else { $align_class = ' text-left'; }
				$output .= '<div class="dtr-testimonial-info-text' . $align_class . '">';
				
				if( $client_name ){
					$output .= '<h5 class="dtr-testimonial-client-name">' . esc_attr( $client_name ) . '</h5>';
				} 
				if( $client_designation ){ 
					$output .= '<span class="dtr-testimonial-client-designation">' . esc_attr( $client_designation ) . '</span>';
				} 
				$output .= '</div>';
				$output .= '</div>';
				$output .= '</div>';
			endwhile;
			$output .= '</div>';
			wp_reset_postdata();
		endif;
		return $output;
	}
}
add_shortcode('dtr_testimonial_carousel', 'charvi_testimonial_carousel_sc');

/*------------------------------------------------------------
 * Recent Posts Carousel
 * @since 1.0
 *------------------------------------------------------------*/
if ( ! function_exists( 'dtr_charvi_recentpost_sc' ) ) {
	function dtr_charvi_recentpost_sc( $atts, $content = null ) {
		extract ( shortcode_atts( array(
			'title'     	=> '',
			'image'			=> '',
			'excerpt'   	=> '',
			'date'   		=> '',
			'pinit'	    	=> '',
			'limit'     	=> -1,
			'order'     	=> 'DESC',
			'orderby'   	=> 'date',
			'cat'	    	=> '',
			'category'		=> '',
			'animation'		=> '', 
		), $atts ) );
	
		$cat = str_replace(' ','-',$cat);
		 
		global $post;
		$args = array(
			'post_type'      => '',
			'posts_per_page' => esc_attr( $limit ),
			'order'          => esc_attr( $order ), 
			'orderby'        => $orderby,
			'post_status'    => 'publish',
			'category_name'  => $cat, 
		);
	
		query_posts( $args );
		$output = '';
		if( have_posts() ) : 
			$output .= '<div class="owl-carousel dtr-recentpost-carousel dtr-owl-theme">';
			while ( have_posts() ) : the_post();
				$output .= '<div class="item dtr-recentpost-carousel-item clearfix">';
				$permalink		= get_permalink();
				$thumb_title	= get_the_title();	
				$post_id 		= get_the_ID();
				$url      		= get_permalink( $post_id );
			
				// thumbnail
				if( has_post_thumbnail() && $image == 'show' ) { 
					$output .=  '<div class="dtr-post-carousel-img dtr-img-scale">' . get_the_post_thumbnail($post->ID, 'medium' ) . '';
					if( $pinit == 'show' ) {
						$output .= '<a href="https://www.pinterest.com/pin/create/button/?url=' .  rawurlencode( esc_url( $url ) ) . '&amp;media=' .  wp_get_attachment_url( get_post_thumbnail_id( $post_id ) ) . '&amp;description=' .  rawurlencode( $thumb_title ) . '" title="" onclick="javascript:window.open(this.href, \'\', \'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=500,width=500\');return false;" class="dtr-pinit-label">' . esc_html__('save','charvi') . '</a>';
					}
					$output .=  '</div>';
				}
				
				if( $title == 'show' || $excerpt  == 'show' || $date == 'show' || $category  == 'show' ) {
				$output .= '<div class="dtr-post-carousel-content">';
				}
				
					// category
					if( $category == 'show' ) {
						$cats = get_the_category( $post->ID );
						if( $cats ) {
							 $output .= '<div class="dtr-meta-category dtr-cat-style">';
						 foreach( $cats as $cat ) {
										$output .= '<a href="' . esc_url( get_category_link( $cat->term_id ) ) . '">'. $cat->name .'</a>';
								}
								 $output .= '</div>';
						}
					}
					
					// title
					if( $title == 'show' ):
						$output .= '<h5 class="dtr-post-carousel-title"><a href="' . esc_url( $permalink ) . '" rel="bookmark">' . esc_attr(get_the_title()) . '</a></h5>';
					endif;	

					// date
					if( $date == 'show' ) {
						$date_title = __( 'On ', 'celebrate' );
						$output .= '<ul class="dtr-meta"><li class="dtr-meta-date"><span class="dtr-meta-title">On </span><a href="' . esc_url( $permalink ) . '" rel="bookmark"><span class="tc-meta-title">' . $date_title . '</span>' . esc_attr(get_the_date()) . '</a></li></ul>';
					}

					// excerpt
					if($excerpt == 'show'):	
						$output .= '<div class="dtr-post-carousel-excerpt">';
						$content = get_the_excerpt();
						$content = str_replace( ']]>', ']]&gt;', $content );
						$output .= $content;
						$output .= '</div>';
					endif;	
					if( $title == 'show' || $excerpt  == 'show' || $date == 'show' || $category  == 'show' ) {
					$output .= '</div>';
					}
				$output .= '</div>'; // item
			endwhile;
			$output .= '</div>';
			wp_reset_query();
		endif;
		return $output;
	}	
}
add_shortcode('dtr_recentposts', 'dtr_charvi_recentpost_sc');