<?php
/**
 * About Widget
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// class starts
if ( ! class_exists( 'CHARVI_About_Widget' ) ) {
	class CHARVI_About_Widget extends WP_Widget {
	
		/**
		 * Register widget
		 */
		public function __construct() {
			$widget_ops = array(
      			'classname' => 'charvi_about_widget',
      			'description' => esc_html__( 'Display About Information', 'charvi' ),
    		);
    		parent::__construct( 'charvi_about_widget', esc_html__( 'Custom: About', 'charvi' ), $widget_ops );
			add_action( 'load-widgets.php', array( $this, 'admin_setup' ), 100 );
		}
		
		/**
		 * Enqueue media scripts
		 */
		public function admin_setup() {
			wp_enqueue_media();
		}

		/**
	 	 * Output the content of the widget
		 */
		public function widget( $args, $instance ) {

			// vars
			$output 		= '';
			$title      	= isset( $instance['title'] ) ? apply_filters( 'widget_title', $instance['title'] ) : '';
			$name   		= empty( $instance['name'] ) ? '' : $instance['name'];
			$job   			= empty( $instance['job'] ) ? '' : $instance['job'];
			$description	= isset( $instance['description'] ) ? $instance['description'] : '';
			$wpautop     	= isset( $instance['wpautop'] ) ? $instance['wpautop'] : '';
			$style			= isset( $instance['style'] ) ? $instance['style'] : 'dtr-about-widget-circle';
			$textalign      = isset( $instance['textalign'] ) ? $instance['textalign'] : 'text-center';
			$image       	= isset( $instance['image'] ) ? esc_url( $instance['image'] ) : '';
	
			// Before widget
			$output .= $args['before_widget'];

			// Widget title
			if ( $title ) {
				$output .= $args['before_title'];
					$output .= $title;
				$output .= $args['after_title'];
			}
			
			// output starts
			$output .= '<div class="dtr-about-widget '. esc_attr( $style ) .' '. esc_attr( $textalign ) .' clearfix">';

				// image
				if ( $image ) :
					$output .= '<div class="dtr-about-widget-img">';
						$output .= '<img src="'. $image .'" alt="'. esc_attr( $title ) .'"/>';
					$output .= '</div>';
				endif;
				
				// name and jon name
				if ( $name != '' || $job != '' ) {
				
				$output .= '<div class="dtr-about-header">';
				$output .= '<h5 class="dtr-about-title">' . wp_kses_post( $name ) . '</h5>'; 
				$output .= '<span class="dtr-about-subtitle">' . wp_kses_post( $job ) . '</span>'; 
				$output .= '</div>';
	
				}

				// description
				$output .= '<div class="dtr-about-widget-desc">';
					if ( 'on' == $wpautop ) {
						$output .= wpautop( wp_kses_post( $description ) );
					} else {
						$output .= wp_kses_post( $description );
					}
				$output .= '</div>';

			$output .= '</div>';
			// output ends

			// After widget
			$output .= $args['after_widget'];

			// output echo
			echo $output;
		
		} 

		/**
		 *  Update the information in the WordPress database
		 */	
		 
		public function update( $new_instance, $old_instance ) {
			$instance                 	= $old_instance;
			$instance['title']      	= strip_tags( $new_instance['title'] );
			$instance['name']  			= isset( $new_instance['name'] ) ? trim( strip_tags( $new_instance['name'] ) ) : '';
			$instance['job']  			= isset( $new_instance['job'] ) ? trim( strip_tags( $new_instance['job'] ) ) : '';
			$instance['description']	= wp_kses_post( $new_instance['description'] );
			$instance['wpautop']     	= ! empty( $new_instance['wpautop'] ) ? 'on' : '';
			$instance['style']   		= strip_tags( $new_instance['style'] );
			$instance['textalign']   	= strip_tags( $new_instance['textalign'] );
			$instance['image']       	= strip_tags( $new_instance['image'] );

			/**
			 * Register strings for WPML translation
			 */
			if ( function_exists ( 'icl_register_string' ) ){
				icl_register_string('About Widget', 'Name', $instance['name']);
				icl_register_string('About Widget', 'Job Name', $instance['job']);
				icl_register_string('About Widget', 'Description', $instance['description']);
				
			} // icl_register_string
				
			return $instance;
		} 

		/**
		 * Add form fields to the widget which will be displayed in the WordPress admin area.
		 */
		public function form( $instance ) {
			
			extract( wp_parse_args( $instance, array(
				'title'         => '',
				'description'	=> '',
				'name'     		=> '',
				'job'     		=> '',
				'wpautop'     	=> '',
				'style'         => 'dtr-about-widget-circle',
				'textalign' 	=> '',
				'image'       	=> '',
			) ) ); ?>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
		<?php esc_attr_e( 'Title', 'charvi' ); ?>
	</label>
	<input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'name' ) ); ?>">
		<?php esc_html_e( 'Name', 'charvi' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'name' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'name' ) ); ?>" type="text" value="<?php echo esc_attr( $name ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'job' ) ); ?>">
		<?php esc_html_e( 'Job Name', 'charvi' ); ?>
		:
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'job' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'job' ) ); ?>" type="text" value="<?php echo esc_attr( $job ); ?>" />
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>">
		<?php esc_attr_e( 'Description', 'charvi' ); ?>
	</label>
	<textarea class="widefat" rows="6" cols="20" id="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'description' ) ); ?>"><?php if ( ! empty( $instance['description'] ) ) {  echo wp_kses_post( $instance['description'] ); } ?>
</textarea>
</p>
<p>
	<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'wpautop' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'wpautop' ) ); ?>" type="checkbox" <?php checked( 'on', $wpautop, true ); ?> />
	<label for="<?php echo esc_attr( $this->get_field_id( 'wpautop' ) ); ?>">
		<?php esc_html_e( 'Automatically add paragraphs', 'charvi' ); ?>
	</label>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>">
		<?php esc_html_e( 'Image Style', 'charvi' ); ?>
		:</label>
	<select id="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'style' ) ); ?>" class="widefat">
		<option value="dtr-about-widget-circle" <?php selected( $style, 'dtr-about-widget-circle' ) ?>>
		<?php esc_html_e( 'Circle', 'charvi' ); ?>
		</option>
		<option value="dtr-about-widget-square" <?php selected( $style, 'dtr-about-widget-square' ) ?>>
		<?php esc_html_e( 'Default', 'charvi' ); ?>
		</option>
	</select>
</p>
<p style="background: #f2f2f2; padding:10px; font-size: 11px;">
	<?php esc_html_e( 'Provide equal width - height image', 'charvi' ); ?>
</p>
<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'textalign' ) ); ?>">
		<?php esc_html_e( 'Text align', 'charvi' ); ?>
		:</label>
	<select id="<?php echo esc_attr( $this->get_field_id( 'textalign' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'textalign' ) ); ?>" class="widefat">
		<option value="text-center" <?php selected( $textalign, 'text-center' ) ?>>
		<?php esc_html_e( 'Default - Center', 'charvi' ); ?>
		</option>
		<option value="text-left" <?php selected( $textalign, 'text-left' ) ?>>
		<?php esc_html_e( 'Left', 'charvi' ); ?>
		</option>
		<option value="text-right" <?php selected( $textalign, 'text-right' ) ?>>
		<?php esc_html_e( 'Right', 'charvi' ); ?>
		</option>
	</select>
</p>

<p>
	<label for="<?php echo esc_attr( $this->get_field_id( 'image' ) ); ?>">
			<?php esc_html_e( 'Image URL', 'charvi' ); ?>
	</label>
	<input class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'image' ) ); ?>" type="text" value="<?php echo esc_attr( $image ); ?>" />
</p>
<?php
		} 
	// class ends
	}
}
register_widget( 'CHARVI_About_Widget' );