<?php
namespace CharviAddons;
use CharviAddons\Widgets\Charvi_Promobox;
use CharviAddons\Widgets\Charvi_Packagebox;
use CharviAddons\Widgets\Charvi_About;
use CharviAddons\Widgets\Charvi_Testimonial_Carousel;
use CharviAddons\Widgets\Charvi_Testimonial_Single;
use CharviAddons\Widgets\Charvi_Testimonial_Single_Var;
use CharviAddons\Widgets\Charvi_Recentposts_Carousel;
use CharviAddons\Widgets\Charvi_Button;
use CharviAddons\Widgets\Charvi_Titlebox;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * Main Plugin Class
 * Register new elementor widget.
 * @since 1.0.0
 */
class Charvi_Elementor_Addons {
	/**
	 * Constructor
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {
		$this->add_actions();
	}
	
	/**
	 * Add Actions
	 * @since 1.0.0
	 * @access private
	 */
	private function add_actions() {
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'on_widgets_registered' ] );
		add_action( 'elementor/init', array( $this, 'add_elementor_category' ) );
	}
	
	/**
	 * On Widgets Registered
	 * @since 1.0.0
	 * @access public
	 */
	public function on_widgets_registered() {
		$this->includes();
		$this->register_widget();
	}
	
	/**
	 * Add Category
	 * @since 1.0.0
	 * @access public
	 */
	 public function add_elementor_category() {
		\Elementor\Plugin::instance()->elements_manager->add_category(
			'dtr-element',
			array(
				'title' => __('Charvi Addons', 'charvi'),
				'icon' => 'fa fa-plug',
			),
			1);
      }

	/**
	 * Includes
	 * @since 1.0.0
	 * @access private
	 */
	private function includes() {
		require __DIR__ . '/widgets/dtr-button.php';
		require __DIR__ . '/widgets/dtr-promobox.php';
		require __DIR__ . '/widgets/dtr-packagebox.php';
		require __DIR__ . '/widgets/dtr-about.php';
		require __DIR__ . '/widgets/dtr-testimonial-carousel.php';
		require __DIR__ . '/widgets/dtr-testimonial-single.php';
		require __DIR__ . '/widgets/dtr-testimonial-single-var.php';
		require __DIR__ . '/widgets/dtr-recentposts-carousel.php';
		require __DIR__ . '/widgets/dtr-title-box.php';
	}
	
	/**
	 * Register Widget
	 * @since 1.0.0
	 * @access private
	 */
	private function register_widget() {
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Charvi_Button() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Charvi_Promobox() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Charvi_Packagebox() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Charvi_About() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Charvi_Testimonial_Carousel() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Charvi_Testimonial_Single() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Charvi_Testimonial_Single_Var() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Charvi_Recentposts_Carousel() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Charvi_Titlebox() );
	}
}
new Charvi_Elementor_Addons();