<?php
namespace CharviAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * About Widget
 */
class Charvi_About extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'aboutbox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'About', 'charvi' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function _register_controls() {
		
		// image control starts
		$this->start_controls_section(
			'section_about_image',
			[
				'label' => __( 'About Image', 'charvi' ),
			]
		);
		
		$this->add_control(
			'about_image',
			[
				'label' => __( 'Choose Image', 'charvi' ),
				'type' => Controls_Manager::MEDIA,
					'selectors' => [
				'{{WRAPPER}} div.dtr-about-image, {{WRAPPER}} .dtr-about-image' => 'background-image: url("{{URL}}");',
			],
			
			]
		);
		
		$this->add_control(
			'about_image_position',
			[
				'label' => __( 'Background Position', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => _x( 'Default', 'Background Control', 'charvi' ),
				'top left' => _x( 'Top Left', 'Background Control', 'charvi' ),
				'top center' => _x( 'Top Center', 'Background Control', 'charvi' ),
				'top right' => _x( 'Top Right', 'Background Control', 'charvi' ),
				'center left' => _x( 'Center Left', 'Background Control', 'charvi' ),
				'center center' => _x( 'Center Center', 'Background Control', 'charvi' ),
				'center right' => _x( 'Center Right', 'Background Control', 'charvi' ),
				'bottom left' => _x( 'Bottom Left', 'Background Control', 'charvi' ),
				'bottom center' => _x( 'Bottom Center', 'Background Control', 'charvi' ),
				'bottom right' => _x( 'Bottom Right', 'Background Control', 'charvi' ),
				],
				'selectors' => [
				'{{WRAPPER}} div.dtr-about-image, {{WRAPPER}} .dtr-about-image' => 'background-position: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'about_image_repeat',
			[
				'label' => __( 'Background Repeat', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => _x( 'Default', 'Background Control', 'charvi' ),
				'no-repeat' => _x( 'No-repeat', 'Background Control', 'charvi' ),
				'repeat' => _x( 'Repeat', 'Background Control', 'charvi' ),
				'repeat-x' => _x( 'Repeat-x', 'Background Control', 'charvi' ),
				'repeat-y' => _x( 'Repeat-y', 'Background Control', 'charvi' ),
				],
				'selectors' => [
				'{{WRAPPER}} div.dtr-about-image, {{WRAPPER}} .dtr-about-image' => 'background-repeat: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'about_image_size',
			[
				'label' => __( 'Background Repeat', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => _x( 'Default', 'Background Control', 'charvi' ),
				'auto' => _x( 'Auto', 'Background Control', 'charvi' ),
				'cover' => _x( 'Cover', 'Background Control', 'charvi' ),
				'contain' => _x( 'Contain', 'Background Control', 'charvi' ),
				],
				'selectors' => [
				'{{WRAPPER}} div.dtr-about-image, {{WRAPPER}} .dtr-about-image' => 'background-size: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// image control ends
		
		// content control starts
		$this->start_controls_section(
			'section_about_content',
			[
				'label' => __( 'About Content', 'charvi' ),
			]
		);

		// title
		$this->add_control(
			'tagline_title',
			[
				'label' => __( 'Tagline', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		// tagline
		$this->add_control(
			'about_tagline',
			[
				'label' => __( 'Tagline Text', 'charvi' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'My Tagline Here', 'charvi' ),
				'placeholder' => __( 'Your Tagline', 'charvi' ),
				'label_block' => true,
			]
		);
		
		// tagline dimention
		$this->add_control(
			'about_tagline_dimension',
			[
				'label' => __( 'Tagline Dimention from Top', 'charvi' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '130', 'charvi' ),
				'description' => __( 'Provide just number, no need of unit. Roughly 20px more than height of tagline.', 'charvi' ),
				'label_block' => true,
			]
		);
		
		// description
		$this->add_control(
			'description_text',
			[
				'name' => 'tab_content',
				'label' => __( 'Content', 'charvi' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __( 'About Me Description', 'charvi' ),
				'show_label' => true,
			]
		);
		
		// button
		$this->add_control(
			'about_btn_text',
			[
				'label' => __( 'Button Text', 'charvi' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'ACCESS', 'charvi' ),
				'description' => __('Leave blank if need to hide button. Visible in caption only if title or subtitle provided.', 'charvi'),
				'placeholder' => __( 'Your Button Text', 'charvi' ),
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'about_btn_link',
			[
				'label' => __( 'Link', 'charvi' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'http://your-link.com',
				'description' => __('Leave blank if link not required', 'charvi'),
				'default' => [
					'url' => '#',
				],
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'charvi' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'about_wrapper_bg_color',
			[
				'label' => __( 'About Background Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div.dtr-about-wrapper, {{WRAPPER}} .dtr-about-wrapper' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'about_content_bg_color',
			[
				'label' => __( 'About Content Background Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div.dtr-about-content, {{WRAPPER}} .dtr-about-content' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'about_content_color',
			[
				'label' => __( 'Content Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div.dtr-about-content, {{WRAPPER}} .dtr-about-content' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'about_heading_color',
			[
				'label' => __( 'Headings in Content Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-about-content h1, {{WRAPPER}} .dtr-about-content h2, {{WRAPPER}} .dtr-about-content h3, {{WRAPPER}} .dtr-about-content h4, {{WRAPPER}} .dtr-about-content h5, {{WRAPPER}} .dtr-about-content h6' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'about_tagline_color',
			[
				'label' => __( 'Tagline Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} span.dtr-about-tagline, {{WRAPPER}} .dtr-about-tagline' => 'color: {{VALUE}};',
				],
			]
		);
		
		// button
		$this->add_control(
			'about_button_control',
			[
				'label' => __( 'Button', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'about_button_bg',
			[
				'label' => __( 'Background Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.themebtn, {{WRAPPER}} .themebtn' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'about_button_border_color',
			[
				'label' => __( 'Border Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.themebtn, {{WRAPPER}} .themebtn' => 'border-color: {{VALUE}};',
				],
			]
		);
			
		$this->add_control(
			'about_button_color',
			[
				'label' => __( 'Text Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} a.themebtn, {{WRAPPER}} .themebtn' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		$html = ''; 
		$html .= '<div class="dtr-about-wrapper clearfix">';
		if ( ! empty( $settings['about_tagline'] ) ) { 
			$html .= sprintf( '<span class="dtr-about-tagline" style="top:%1$spx">%2$s</span>', $settings['about_tagline_dimension'], $settings['about_tagline'] );
		}  
		$html .= '<div class="dtr-about-image"></div>';
		$html .= '<div class="dtr-about-content">';
		if ( ! empty( $settings['description_text'] ) ) {
			$html .= sprintf( '<div class="dtr-about-description">%s</div>', $settings['description_text'] );
		}
		if ( ! empty( $settings['about_btn_text'] ) ) {
				$title_html = $settings['about_btn_text'];
				if ( ! empty( $settings['about_btn_link']['url'] ) ) {
					$link = esc_url( $settings['about_btn_link']['url'] );
				} 
				$target = $settings['about_btn_link']['is_external'] ? 'target="_blank"' : '';
				$nofollow = $settings['about_btn_link']['nofollow'] ? 'rel="nofollow"' : '';
				$html .= sprintf( '<a class="dtr-about-btn themebtn" href="%1$s" %2$s %3$s>' . $title_html . '</a>', $link, $target, $nofollow );
		}
		$html .= '</div>';
		$html .= '</div>';
		echo $html;	
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<#
		var html = '<div class="dtr-about-wrapper clearfix">';
		if ( settings.about_tagline ) {
			if ( settings.about_tagline_dimension ) {
				var about_tagline_top_dimension = settings.about_tagline_dimension;
			} else { var title_html = ''; }
			html += '<span class="dtr-about-tagline" style="top:' + about_tagline_top_dimension + 'px">' + settings.about_tagline + '</span>';
		}
		html += '<div class="dtr-about-image"></div>';
		html += '<div class="dtr-about-content">';
		if ( settings.description_text ) {
			html += '<div class="dtr-about-description">' + settings.description_text + '</div>';
		}
		if ( settings.about_btn_text ) {
			html += '<a class="dtr-about-btn themebtn">' + settings.about_btn_text + '</a>';
		}
		html += '</div>';
		html += '</div>';
		print( html );
		#>
		<?php
	}
}