<?php
namespace CharviAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Promobox Widget
 */
class Charvi_Promobox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'promobox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Promobox', 'charvi' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		  return array('dtr-element');

	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function _register_controls() {
		
		// image control starts
		$this->start_controls_section(
			'section_promobox_image',
			[
				'label' => __( 'Promobox Background', 'charvi' ),
			]
		);
		
		$this->add_control(
			'promobox_bg_color',
			[
				'label' => __( 'Background Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} div.dtr-promobox-wrapper, {{WRAPPER}} .dtr-promobox-wrapper' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'promobox_bg_image',
			[
				'label' => __( 'Background Image', 'charvi' ),
				'type' => Controls_Manager::MEDIA,
					'selectors' => [
				'{{WRAPPER}} div.dtr-promobox-wrapper, {{WRAPPER}} .dtr-promobox-wrapper' => 'background-image: url("{{URL}}");',
			],
			
			]
		);
		
		$this->add_control(
			'promobox_bg_image_position',
			[
				'label' => __( 'Background Position', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => _x( 'Default', 'Background Control', 'charvi' ),
				'top left' => _x( 'Top Left', 'Background Control', 'charvi' ),
				'top center' => _x( 'Top Center', 'Background Control', 'charvi' ),
				'top right' => _x( 'Top Right', 'Background Control', 'charvi' ),
				'center left' => _x( 'Center Left', 'Background Control', 'charvi' ),
				'center center' => _x( 'Center Center', 'Background Control', 'charvi' ),
				'center right' => _x( 'Center Right', 'Background Control', 'charvi' ),
				'bottom left' => _x( 'Bottom Left', 'Background Control', 'charvi' ),
				'bottom center' => _x( 'Bottom Center', 'Background Control', 'charvi' ),
				'bottom right' => _x( 'Bottom Right', 'Background Control', 'charvi' ),
				],
				'selectors' => [
				'{{WRAPPER}} div.dtr-promobox-wrapper, {{WRAPPER}} .dtr-promobox-wrapper' => 'background-position: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'promobox_bg_image_repeat',
			[
				'label' => __( 'Background Repeat', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => _x( 'Default', 'Background Control', 'charvi' ),
				'no-repeat' => _x( 'No-repeat', 'Background Control', 'charvi' ),
				'repeat' => _x( 'Repeat', 'Background Control', 'charvi' ),
				'repeat-x' => _x( 'Repeat-x', 'Background Control', 'charvi' ),
				'repeat-y' => _x( 'Repeat-y', 'Background Control', 'charvi' ),
				],
				'selectors' => [
				'{{WRAPPER}} div.dtr-promobox-wrapper, {{WRAPPER}} .dtr-promobox-wrapper' => 'background-repeat: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'promobox_bg_image_size',
			[
				'label' => __( 'Background Repeat', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => _x( 'Default', 'Background Control', 'charvi' ),
				'auto' => _x( 'Auto', 'Background Control', 'charvi' ),
				'cover' => _x( 'Cover', 'Background Control', 'charvi' ),
				'contain' => _x( 'Contain', 'Background Control', 'charvi' ),
				],
				'selectors' => [
				'{{WRAPPER}} div.dtr-promobox-wrapper, {{WRAPPER}} .dtr-promobox-wrapper' => 'background-size: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// image control ends
		
		// content control starts
		$this->start_controls_section(
			'section_promobox',
			[
				'label' => __( 'Promobox Content', 'charvi' ),
			]
		);

		// title
		$this->add_control(
			'promobox_title',
			[
				'label' => __( 'Title', 'charvi' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'This is the heading', 'charvi' ),
				'placeholder' => __( 'Your Title', 'charvi' ),
				'label_block' => true,
			]
		);
		
		// tagline
		$this->add_control(
			'promobox_subtitle',
			[
				'label' => __( 'Subtitle', 'charvi' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Freebie', 'charvi' ),
				'placeholder' => __( 'Your Subtitle', 'charvi' ),
				'label_block' => true,
			]
		);

		// button
		$this->add_control(
			'promobox_btn_text',
			[
				'label' => __( 'Button Text', 'charvi' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'ACCESS', 'charvi' ),
				'description' => __('Leave blank if need to hide button. Visible in caption only if title or subtitle provided.', 'charvi'),
				'placeholder' => __( 'Your Button Text', 'charvi' ),
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'wrap_in_link',
			[
				'label' => __( 'Wrap Promobox in Link', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'hide',
				'options' => [
					'hide' => __( 'No', 'charvi' ),
					'show' => __( 'Yes', 'charvi' ),
				],
			]
		);
		
		$this->add_control(
			'promobox_btn_link',
			[
				'label' => __( 'Link', 'charvi' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'http://your-link.com',
				'description' => __('Leave blank if link not required', 'charvi'),
				'default' => [
					'url' => '#',
				],
			]
		);
		
		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'charvi' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);
		$this->end_controls_section();
		// content control ends
		
		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'charvi' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		// title
		$this->add_control(
			'promobox_title_control',
			[
				'label' => __( 'Title', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'promobox_title_color',
			[
				'label' => __( 'Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-promobox-title' => 'color: {{VALUE}};',
				],
			]
		);
		// tagline
		$this->add_control(
			'promobox_subtitle_control',
			[
				'label' => __( 'Sub Title', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
	
		$this->add_control(
			'promobox_subtitle_color',
			[
				'label' => __( 'Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .dtr-promobox-subtitle' => 'color: {{VALUE}};',
				],
			]
		);
		
		// button
		$this->add_control(
			'promobox_button_control',
			[
				'label' => __( 'Button', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'promobox_button_bg',
			[
				'label' => __( 'Background Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.dtr-promobox-btn, {{WRAPPER}} .dtr-promobox-btn' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'promobox_button_border_color',
			[
				'label' => __( 'Border Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.dtr-promobox-btn, {{WRAPPER}} .dtr-promobox-btn' => 'border-color: {{VALUE}};',
				],
			]
		);
			
		$this->add_control(
			'promobox_button_color',
			[
				'label' => __( 'Text Color', 'charvi' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} a.dtr-promobox-btn, {{WRAPPER}} .dtr-promobox-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		// style control ends
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		$html = '';
		if ( empty( $settings['promobox_btn_text'] ) ) {
			$class = 'promobox-has-no-button';
		} else { 
			$class = ''; 
		}
		$html .= '<div class="dtr-promobox-wrapper ' . $class  . '">';
		$html .= '<div class="dtr-promobox">';
		if ( ! empty( $settings['promobox_subtitle'] ) ||  ! empty( $settings['promobox_title'] )  ) {
			$html .= '<div class="dtr-promobox-caption">';
			if ( ! empty( $settings['promobox_subtitle'] ) ) {
				$html .= sprintf( '<span class="dtr-promobox-subtitle">%s</span>', $settings['promobox_subtitle'] );
			}
			if ( ! empty( $settings['promobox_title'] ) ) {
				$html .= sprintf( '<h5 class="dtr-promobox-title">%s</h5>', $settings['promobox_title'] );
			}
			if ( ! empty( $settings['promobox_btn_text'] ) ) {
				$title_html = $settings['promobox_btn_text'];
				if ( ! empty( $settings['promobox_btn_link']['url'] ) ) {
					$link = esc_url( $settings['promobox_btn_link']['url'] );
				} 
				$target = $settings['promobox_btn_link']['is_external'] ? 'target="_blank"' : '';
				$nofollow = $settings['promobox_btn_link']['nofollow'] ? 'rel="nofollow"' : '';
				$html .= sprintf( '<a class="dtr-promobox-btn themebtn" href="%1$s" %2$s %3$s>' . $title_html . '</a>', $link, $target, $nofollow );
			}
		$html .= '</div>';
		}
		if ( ! empty( $settings['promobox_btn_link']['url'] ) && 'show' === $settings['wrap_in_link'] ) {
			$link = esc_url( $settings['promobox_btn_link']['url'] );
			$target = $settings['promobox_btn_link']['is_external'] ? 'target="_blank"' : '';
			$nofollow = $settings['promobox_btn_link']['nofollow'] ? 'rel="nofollow"' : '';
			$html .= sprintf( '<a class="dtr-link-wrap" href="%1$s" %2$s %3$s></a>', $link, $target, $nofollow );
		}	
		$html .= '</div>';
		$html .= '</div>';
		echo $html;
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<#
		if ( settings.promobox_btn_text ) {
			$class = '';
		} else { $class = 'promobox-has-no-button'; }
		var html = '<div class="dtr-promobox-wrapper ' + $class + '"><div class="dtr-promobox">';
		var hasContent = !! ( settings.promobox_subtitle || settings.promobox_title );
		if ( hasContent ) {
			html += '<div class="dtr-promobox-caption">';
		
				if ( settings.promobox_subtitle ) {
					html += '<span class="dtr-promobox-subtitle">' + settings.promobox_subtitle + '</span>';
				}
			
				if ( settings.promobox_title ) {
					var title_html = settings.promobox_title;
					html += '<h5 class="dtr-promobox-title">' + title_html + '</h5>';
				}
				if ( settings.promobox_btn_text ) {
					html += '<a class="dtr-promobox-btn themebtn">' + settings.promobox_btn_text + '</a>';
				}
			
			html += '</div>';
		}
		html += '</div></div>';	
		print( html );
		#>
		<?php
	}
}