<?php
namespace CharviAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Recentposts Carousel Widget
 */
class Charvi_Recentposts_Carousel extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'recentpostscarousel';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Recent Posts Carousel', 'charvi' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function _register_controls() {
		
		// content control starts
		$this->start_controls_section(
			'section_testimonial_content',
			[
				'label' => __( 'Posts Carousel', 'charvi' ),
			]
		);
		
		$this->add_control(
			'posts_carousel_info',
			[
				'label' => __( 'Save and refresh for posts to be visible in editor.', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'post_limit',
			[
				'label' => __( 'Number of posts to show in carousel', 'charvi' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 2,
				'min' => 2,
				'step' => 1,
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> __( 'Show', 'charvi' ),
					'hide'  	=> __( 'Hide', 'charvi' ),
				],
			]
		);
		
		$this->add_control(
			'image',
			[
				'label' => __( 'Image', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> __( 'Show', 'charvi' ),
					'hide'  	=> __( 'Hide', 'charvi' ),
				],
			]
		);
		
		$this->add_control(
			'date',
			[
				'label' => __( 'Date', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> __( 'Show', 'charvi' ),
					'hide'  	=> __( 'Hide', 'charvi' ),
				],
			]
		);
		
		$this->add_control(
			'excerpt',
			[
				'label' => __( 'Excerpt', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> __( 'Show', 'charvi' ),
					'hide'  	=> __( 'Hide', 'charvi' ),
				],
			]
		);
		
		$this->add_control(
			'pinit',
			[
				'label' => __( 'Pin It lable', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> __( 'Show', 'charvi' ),
					'hide'  	=> __( 'Hide', 'charvi' ),
				],
			]
		);
		
		$this->add_control(
			'category',
			[
				'label' => __( 'Category', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'show',
				'options' => [
					'show'	=> __( 'Show', 'charvi' ),
					'hide'  	=> __( 'Hide', 'charvi' ),
				],
			]
		);
		
		$this->add_control(
			'post_orderby',
			[
				'label' => __( 'Sort Testimonials By', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'date' 	=> __( 'Date', 'charvi' ),
					'rand' 	=> __( 'Random', 'charvi' ),
					'title'	=> __( 'Title', 'charvi' ),
				],
			]
		);
		
		$this->add_control(
			'post_order',
			[
				'label' => __( 'Arrange Sorted Testimonials', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => [
					'DESC'	=> __( 'Descending', 'charvi' ),
					'ASC'  	=> __( 'Ascending', 'charvi' ),
				],
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'charvi' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'contentbg_color',
			[
				'label' => __( 'Content Background Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-post-carousel-content' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	 protected function render() {
		$settings = $this->get_settings(); 
		echo do_shortcode('[dtr_recentposts limit="' . $settings['post_limit'] . '" orderby="' . $settings['post_orderby'] . '" order="' . $settings['post_order'] . '" image="' . $settings['image'] . '" title="' . $settings['title'] . '" category="' . $settings['category'] . '" date="' . $settings['date'] . '" pinit="' . $settings['pinit'] . '" excerpt="' . $settings['excerpt'] . '"]');
		
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function _content_template() { }
}