<?php
namespace CharviAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Testimonial Widget
 */
class Charvi_Testimonial_Single extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'testimonialsingle';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Testimonial Single Item', 'charvi' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function _register_controls() {
		
		// content control starts
		$this->start_controls_section(
			'section_testimonial_content',
			[
				'label' => __( 'Testimonial Single Item', 'charvi' ),
			]
		);

		// testimonial id
		$this->add_control(
			'testimonial_id',
			[
				'label' => __( 'ID of Testimonial to Display', 'charvi' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'ID', 'charvi' ),
				'placeholder' => __( 'ID of Testimonial to Display', 'charvi' ),
				'description' => __( 'Save and refresh for testimonial to be visible in editor', 'charvi' ),
				'label_block' => true,
			]
		);
		
		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'charvi' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'about_tagline_color',
			[
				'label' => __( 'Quote Icon Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-testimonial::before' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		if ( ! empty( $settings['testimonial_id'] ) ) {
		echo do_shortcode('[dtr_testimonial id="' . $settings['testimonial_id'] . '"]');
		}
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function _content_template() {  }
}