<?php
namespace CharviAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Control_Media;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * About Widget
 */
class Charvi_Titlebox extends Widget_Base {

	/**
	 * Retrieve widget name.
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'titlebox';
	}

	/**
	 * Retrieve widget title.
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Title Box', 'charvi' );
	}

	/**
	 * Retrieve widget icon.
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('dtr-element');
	}
	

	/**
	 * Register widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @access protected
	 */
	protected function _register_controls() {
	
		// content control starts
		$this->start_controls_section(
			'section_about_content',
			[
				'label' => __( 'Title Box Content', 'charvi' ),
			]
		);

		// title
		$this->add_control(
			'titlebox_title_control',
			[
				'label' => __( 'Title', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		// title
		$this->add_control(
			'titlebox_title',
			[
				'label' => __( 'Title Text', 'charvi' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Title Goes Here', 'charvi' ),
				'placeholder' => __( 'Your Title Here', 'charvi' ),
				'label_block' => true,
				'show_label' => false,
			]
		);
		
				
		$this->add_control(
			'form_style',
			[
				'label' => __( 'Horizonatal Style to Subscribe Form if Added in content as shortcode.', 'charvi' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'yes',
				'label_block' => true,
				'show_label' => true,
				'options' => [
					'yes'	=> __( 'Yes', 'charvi' ),
					'no'  	=> __( 'No', 'charvi' ),
				],
			]
		);
		
		// description
		$this->add_control(
			'description_text',
			[
				'name' => 'tab_content',
				'label' => __( 'Content', 'charvi' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __( 'Title Box Content', 'charvi' ),
				'show_label' => true,
			]
		);

		$this->end_controls_section();
		// content control ends

		// style control starts
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'charvi' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		
		
		// title
		$this->add_control(
			'titlebox_title_style_control',
			[
				'label' => __( 'Title', 'charvi' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
				
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'box_title_typo',
                'selector' => '{{WRAPPER}} .dtr-title-box-title',
            ]
        );
		
		$this->add_control(
			'box_title_bg_color',
			[
				'label' => __( 'Title Background Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} span.dtr-title-box-title, {{WRAPPER}} .dtr-title-box-title' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'box_title_color',
			[
				'label' => __( 'Title Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} span.dtr-title-box-title, {{WRAPPER}} .dtr-title-box-title' => 'color: {{VALUE}};',
				],
			]
		);
		
		// title
		$this->add_control(
			'titlebox_content_style_control',
			[
				'label' => __( 'Content', 'charvi' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		
		$this->add_control(
			'box_bg_color',
			[
				'label' => __( 'Box Background Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div.dtr-title-box, {{WRAPPER}} .dtr-title-box' => 'background-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'box_title_border_color',
			[
				'label' => __( 'Box Border Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div.dtr-title-box, {{WRAPPER}} .dtr-title-box' => 'border-color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'box_content_color',
			[
				'label' => __( 'Content Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div.dtr-title-box, {{WRAPPER}} .dtr-title-box' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_control(
			'box_heading_color',
			[
				'label' => __( 'Headings in Content Color', 'charvi' ),
				'default' => '',
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dtr-title-box h1, {{WRAPPER}} .dtr-title-box h2, {{WRAPPER}} .dtr-title-box h3, {{WRAPPER}} .dtr-title-box h4, {{WRAPPER}} .dtr-title-box h5, {{WRAPPER}} .dtr-title-box h6' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		// style control ends
		
	}

	/**
	 * Render widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings(); 
		$html = ''; 
		if ( 'yes' === $settings['form_style'] ) {
			$class = ' dtr-subscribe-form-center';
		} else { 
			$class = ''; 
		}
		$html .= '<div class="dtr-title-box clearfix' . $class  . '">';
		if ( ! empty( $settings['titlebox_title'] ) ) {
			$html .= sprintf( '<span class="dtr-title-box-title">%s</span>', $settings['titlebox_title'] ); 
		}  
		if ( ! empty( $settings['description_text'] ) ) {
			$html .= sprintf( '<div class="dtr-title-box-description clearfix">%s</div>', $settings['description_text'] );
		}
		$html .= '</div>';
		echo $html;	
	}

	/**
	 * Render widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<#
		var html = '<div class="dtr-title-box clearfix">';
		if ( settings.titlebox_title ) {
			html += '<span class="dtr-title-box-title">' + settings.titlebox_title + '</span>';
		}
		if ( settings.description_text ) {
			html += '<div class="dtr-title-box-description clearfix">' + settings.description_text + '</div>';
		}
		html += '</div>';
		print( html );
		#>
		<?php
	}
}